@@ -1,5 +1,6 @@
 use strict;
 use Etk;
+use Etk::Constants qw/:box/;
 
 my $win = Etk::Window->new();
 
@@ -7,11 +8,11 @@ my $vbox = Etk::VBox->new(0, 0);
 
 my $button = Etk::Button::new_with_label("click me!");
 $button->signal_connect("clicked", \&click_cb1, "click_cb1_data");
-$vbox->PackStart($button, 1, 1, 5);
+$vbox->Append($button, BoxStart, BoxNone, 1);
 
 my $button2 = Etk::Button::new_with_label("click me too!");
 $button2->signal_connect("clicked", \&click_cb2);
-$vbox->PackStart($button2, 0, 0, 2);
+$vbox->Append($button2, BoxStart, BoxNone, 0);
 
 
 my $tree = Etk::Tree->new();
@@ -23,22 +24,22 @@ $tree->SizeRequestSet(320, 400);
 $tree->Build();
 
 my $row = $tree->Append();
-$row->FieldTextSet($col1, "Wee!!!!");
-$row->FieldProgressBarSet($col2, 0.5, " Loading ... ");
+$row->FieldsSet($col1, "Wee!!!!");
+$row->FieldsSet($col2, 0.5, " Loading ... ");
 
 $row = $tree->Append();
-$row->field_text_set($col1, "Second Line");
-$row->FieldProgressBarSet($col2, 0.2, " Reading ... ");
+$row->FieldsSet($col1, "Second Line");
+$row->FieldsSet($col2, 0.2, " Reading ... ");
 
-$vbox->PackStart($tree, 0, 0, 0);
+$vbox->Append($tree, BoxStart, BoxNone, 0);
 
 sub click_cb1
 {
     my $self = shift;
     my $data = shift;
     print "click_cb1! (data=$data)\n";
-    my ($padding, $expand, $fill, $pack_end) = $vbox->ChildPackingGet($self);
-    print "padding = $padding, expand = $expand, fill = $fill, pack_end = $pack_end\n";
+    my ($fill, $padding) = $vbox->ChildPackingGet($self);
+    print "padding = $padding, fill = $fill\n";
 }
 
 sub click_cb2
